Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Mailer ¶
type Mailer struct {
// contains filtered or unexported fields
}
Interface between the server and the service it uses to send emails.
func (*Mailer) Send ¶
func (mailer *Mailer) Send(options SendOptions) error
Sends an email with the specified contents to the specified email address.
type SendOptions ¶
type SendOptions struct {
// Body of the email to be sent.
Message string
// Subject of the email to be sent.
Subject string
// Email address of the receipient of the email to be sent.
ToEmailAddress string
}
Options configuring Mailer#Send(...).
Click to show internal directories.
Click to hide internal directories.