Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Session ¶
type Session struct {
// True if the user is logged in.
IsUserLoggedIn bool
// Unique identifier of the logged in user if the user is logged in.
UserID uint
// contains filtered or unexported fields
}
Encapsulates the session information encoded within a particular request.
func ExtractFrom ¶
Extracts the Session embedded within the specified context, panicing if no such embedded Session exists.
Click to show internal directories.
Click to hide internal directories.